@@ -10,7 +10,9 @@ from webspace.cms.blocks.common import \
     EntryBlock, \
     EmbedWithSizeBlock, \
     FormBlock, \
-    GallerySliderBlock
+    GallerySliderBlock, \
+    NumbersBlock, \
+    AccordionBlock
 
 
 class ComponentTextEntry(EntryBlock):
@@ -27,7 +29,9 @@ class ComponentTextEntry(EntryBlock):
             ('image', ImageWithSizeBlock()),
             ('embed', EmbedWithSizeBlock()),
             ('form', FormBlock()),
-            ('gallery_slider', GallerySliderBlock())
+            ('gallery_slider', GallerySliderBlock()),
+            ('numbers', NumbersBlock()),
+            ('accordion', AccordionBlock()),
         ],
         max_num=1,
         required=False
