@@ -9,6 +9,8 @@ class PricingItem(blocks.StructBlock):
     header_title = blocks.CharBlock()
     header_description = blocks.TextBlock()
     price_month = blocks.DecimalBlock()
+    price_unit = blocks.CharBlock(required=False)
+    price_promotion = blocks.CharBlock(required=False)
     button = ButtonBlock()
     footer_title = blocks.CharBlock()
     features = blocks.ListBlock(blocks.StructBlock([
